@@ -1,7 +1,7 @@
 from naomi.eeprom import NaomiEEPRom, NaomiEEPRomException
 from naomi.generic_patch import force_freeplay, force_no_attract_sound
 from naomi.rom import NaomiRom, NaomiRomRegionEnum, NaomiRomVersionEnum, NaomiExecutable, NaomiRomSection, NaomiRomException
-from naomi.rom_patch import NaomiSettingsPatcher, NaomiSettingsPatcherException, NaomiSettingsTypeEnum, get_default_trojan, add_or_update_trojan, add_or_update_section
+from naomi.rom_patch import NaomiSettingsPatcher, NaomiSettingsPatcherException, get_default_trojan, add_or_update_trojan, add_or_update_section
 
 __all__ = [
     "NaomiRom",
@@ -14,7 +14,6 @@ __all__ = [
     "NaomiEEPRomException",
     "NaomiSettingsPatcher",
     "NaomiSettingsPatcherException",
-    "NaomiSettingsTypeEnum",
     "force_freeplay",
     "force_no_attract_sound",
     "get_default_trojan",
